==> wxwidgets_3.3.2-52_arm64-windows-static.zip: installed/arm64-windows-static/share/wxwidgets/wxWidgetsTargets-debug.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Debug".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "Debug"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "C;CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_baseu-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/debug/lib/libwx_baseu-3.3-Windows.lib" )

# Import target "wx::wxnet" for configuration "Debug"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_net-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_net-3.3-Windows.lib" )

# Import target "wx::wxcore" for configuration "Debug"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_core-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_core-3.3-Windows.lib" )

# Import target "wx::wxadv" for configuration "Debug"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_adv-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_adv-3.3-Windows.lib" )

# Import target "wx::wxaui" for configuration "Debug"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_aui-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_aui-3.3-Windows.lib" )

# Import target "wx::wxhtml" for configuration "Debug"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_html-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_html-3.3-Windows.lib" )

# Import target "wx::wxpropgrid" for configuration "Debug"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_propgrid-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_propgrid-3.3-Windows.lib" )

# Import target "wx::wxribbon" for configuration "Debug"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_ribbon-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_ribbon-3.3-Windows.lib" )

# Import target "wx::wxrichtext" for configuration "Debug"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_richtext-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_richtext-3.3-Windows.lib" )

# Import target "wx::wxwebview" for configuration "Debug"
set_property(TARGET wx::wxwebview APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxwebview PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_webview-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxwebview )
list(APPEND _cmake_import_check_files_for_wx::wxwebview "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_webview-3.3-Windows.lib" )

# Import target "wx::wxscintilla" for configuration "Debug"
set_property(TARGET wx::wxscintilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxscintilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwxscintilla-3.3.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxscintilla )
list(APPEND _cmake_import_check_files_for_wx::wxscintilla "${_IMPORT_PREFIX}/debug/lib/libwxscintilla-3.3.lib" )

# Import target "wx::wxlexilla" for configuration "Debug"
set_property(TARGET wx::wxlexilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxlexilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwxlexilla-3.3.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxlexilla )
list(APPEND _cmake_import_check_files_for_wx::wxlexilla "${_IMPORT_PREFIX}/debug/lib/libwxlexilla-3.3.lib" )

# Import target "wx::wxstc" for configuration "Debug"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_stc-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_stc-3.3-Windows.lib" )

# Import target "wx::wxxrc" for configuration "Debug"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_xrc-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_xrc-3.3-Windows.lib" )

# Import target "wx::wxgl" for configuration "Debug"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_gl-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_gl-3.3-Windows.lib" )

# Import target "wx::wxqa" for configuration "Debug"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_qa-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/debug/lib/libwx_mswu_qa-3.3-Windows.lib" )

# Import target "wx::wxxml" for configuration "Debug"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_xml-3.3-Windows.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/debug/lib/libwx_baseu_xml-3.3-Windows.lib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> wxwidgets_3.3.2-71-r5_arm64-windows-static.zip: installed/arm64-windows-static/share/wxwidgets/wxWidgetsTargets-debug.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Debug".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "Debug"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "C;CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxbase33ud.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/debug/lib/wxbase33ud.lib" )

# Import target "wx::wxnet" for configuration "Debug"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_net.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_net.lib" )

# Import target "wx::wxcore" for configuration "Debug"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_core.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_core.lib" )

# Import target "wx::wxadv" for configuration "Debug"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_adv.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_adv.lib" )

# Import target "wx::wxaui" for configuration "Debug"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_aui.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_aui.lib" )

# Import target "wx::wxhtml" for configuration "Debug"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_html.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_html.lib" )

# Import target "wx::wxpropgrid" for configuration "Debug"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_propgrid.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_propgrid.lib" )

# Import target "wx::wxribbon" for configuration "Debug"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_ribbon.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_ribbon.lib" )

# Import target "wx::wxrichtext" for configuration "Debug"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_richtext.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_richtext.lib" )

# Import target "wx::wxscintilla" for configuration "Debug"
set_property(TARGET wx::wxscintilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxscintilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxscintillad.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxscintilla )
list(APPEND _cmake_import_check_files_for_wx::wxscintilla "${_IMPORT_PREFIX}/debug/lib/wxscintillad.lib" )

# Import target "wx::wxlexilla" for configuration "Debug"
set_property(TARGET wx::wxlexilla APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxlexilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxlexillad.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxlexilla )
list(APPEND _cmake_import_check_files_for_wx::wxlexilla "${_IMPORT_PREFIX}/debug/lib/wxlexillad.lib" )

# Import target "wx::wxstc" for configuration "Debug"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_stc.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_stc.lib" )

# Import target "wx::wxxrc" for configuration "Debug"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_xrc.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_xrc.lib" )

# Import target "wx::wxgl" for configuration "Debug"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_gl.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_gl.lib" )

# Import target "wx::wxqa" for configuration "Debug"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_qa.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/debug/lib/wxmsw33ud_qa.lib" )

# Import target "wx::wxxml" for configuration "Debug"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "CXX"
  IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_xml.lib"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/debug/lib/wxbase33ud_xml.lib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
